@@ -69,6 +69,10 @@ pub enum Error {
     OverflowError(String),
     /// Array is too big
     ArrayTooLong,
+    /// Failed to sign
+    SigningError(String),
+    /// Generic error
+    GenericError(String),
 }
 
 impl fmt::Display for Error {
@@ -80,6 +84,8 @@ impl fmt::Display for Error {
             Error::WriteError(ref io) => fmt::Display::fmt(io, f),
             Error::UnderflowError(ref s) => fmt::Display::fmt(s, f),
             Error::OverflowError(ref s) => fmt::Display::fmt(s, f),
+            Error::SigningError(ref s) => fmt::Display::fmt(s, f),
+            Error::GenericError(ref s) => fmt::Display::fmt(s, f),
             Error::ArrayTooLong => write!(f, "Array too long"),
         }
     }
@@ -94,6 +100,8 @@ impl error::Error for Error {
             Error::WriteError(ref io) => Some(io),
             Error::UnderflowError(ref _s) => None,
             Error::OverflowError(ref _s) => None,
+            Error::SigningError(ref _s) => None,
+            Error::GenericError(ref _s) => None,
             Error::ArrayTooLong => None,
         }
     }
